// Stata code for:
// Jann, Ben, Julia Jerke, Ivar Krumpal (2012). Asking Sensitive Questions Using
// the Crosswise Model: An Experimental Survey Measuring Plagiarism. Public
// Opinion Quarterly 76(1): 32-49. 

// may need to install following user packages:
// ssc install fre
// ssc install estout

version 10.0
clear all
set type double
qui set memory 50m
set more off
capture log close
log using crosswise09.log, replace

use crosswise09.dta


// Number of Observations

fre uni

fre version

fre f7

tab uni version, chi2 exact

gen byte touse = (f7!=1) | inlist(b1,1,2) | inlist(b2,1,2) ///
                         | inlist(f11,1,2) | inlist(f12,1,2)
fre touse

fre version if touse

tab uni version if touse, chi2 exact


// Item-Nonresponse

gen byte partial    = b1==1  if inlist(b1,1,2)  & version==1 & touse
gen byte severe     = b2==1  if inlist(b2,1,2)  & version==1 & touse
replace  partial    = f11==1 if inlist(f11,1,2) & version==2 & touse
replace  severe     = f12==1 if inlist(f12,1,2) & version==2 & touse

gen byte missing = (partial>=.)
tab version missing if touse, missing row
drop missing
gen byte missing = (severe>=.)
tab version missing if touse, missing row
drop missing
gen byte missing = (partial>=.) | (severe>=.)
tab version missing if touse, missing row
drop missing

count if (partial<.) & (severe>=.) & touse
count if (partial>=.) & (severe<.) & touse


// Table 1: Descriptives

su f2 if touse
egen byte agecat = cut(f2) if touse, at(18,23,28,`r(max)')
tab agecat version if touse, chi2 exact col

tab f1 version if touse, chi2 exact col

tab f3 version if touse, chi2 exact col


// Table 2: Prevalence estimates

gen byte crosswise  = version==1 if touse
gen pyes            = cond(crosswise, 0.25, 1) if touse

// - direct questioning

reg partial if crosswise==0
reg severe  if crosswise==0

// - crosswise model

cwreg partial if crosswise, pyes(pyes)
cwreg severe  if crosswise, pyes(pyes)

// - difference model

cwreg partial crosswise, pyes(pyes) robust hc2
cwreg severe  crosswise, pyes(pyes) robust hc2

cwlogit partial crosswise, pyes(pyes) robust
cwlogit severe  crosswise, pyes(pyes) robust

// - estimates by university

foreach uni in 1 2 3 {
    quietly {
    di _n as txt "==> uni = 1 (`: lab (uni) `uni'')"
    eststo DQ_partial: reg partial if crosswise==0 & uni==`uni'
    eststo DQ_severe : reg severe  if crosswise==0 & uni==`uni'

    eststo CW_partial: cwreg partial if crosswise & uni==`uni', pyes(pyes)
    eststo CW_severe : cwreg severe  if crosswise & uni==`uni', pyes(pyes)
    }
    esttab *_partial *_severe, b(1) se(1) nostar transform(@*100 100) ///
        mti nonum title("Prevalence estimates: `: lab (uni) `uni''")
    eststo clear
}


// Table 3: Regression estimates

gen byte female     = f1==2 if inlist(f1,1,2)
gen byte internet   = f8_4==1
gen byte students   = f8_5==1
gen byte papers3or4 = f7==3 if f7<.
gen byte papers5    = f7==4 if f7<.
gen byte zurich     = uni==1
gen byte munich     = uni==2
gen byte leipzig    = uni==3

su partial crosswise zurich munich leipzig female  ///
    papers3or4 papers5 internet students if partial<.
su partial crosswise zurich munich leipzig female  ///
    papers3or4 papers5 internet students if partial<. & crosswise==1

eststo cw_reg: cwreg partial ///
    zurich leipzig ///
    female papers3or4 papers5 internet students  ///
    if crosswise, pyes(pyes) robust
test zurich = leipzig

eststo cw_logit: cwlogit partial ///
    zurich leipzig ///
    female papers3or4 papers5 internet students ///
    if crosswise, pyes(pyes) robust
test zurich = leipzig

eststo all_reg: cwreg partial crosswise ///
    zurich leipzig ///
    female papers3or4 papers5 internet students ///
    , pyes(pyes) robust
test zurich = leipzig

eststo all_logit: cwlogit partial crosswise ///
    zurich leipzig ///
    female papers3or4 papers5 internet students ///
    , pyes(pyes) nolog robust
test zurich = leipzig

esttab cw_reg all_reg cw_logit all_logit, order(crosswise) ///
    compress star(+ 0.1 * 0.05 ** 0.01 *** 0.001) b(2) se(2)


capt n log close
exit
